==> open-xchange-guard-ui_1.2.0.orig.tar.bz2: open-xchange-guard-ui-1.2.0/oxguard-ui/apps/oxguard/mail/oxguard_mail.js <==
/**
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) Open-Xchange Inc., 2006-2011
 */
define('oxguard/mail/oxguard_mail', ['io.ox/core/extensions',
                                     'oxguard/oxguard_core',
                              'gettext!oxguard/mail/oxguard_mail'],
                              function (ext, oxguard, gt) {
    'use strict';
    
    var encrPrivKey = '';

    
    
    ////////////////////////   RECEIVE / READ
    

    
    function loadKeyClick(evt) {
        var file = evt.target.files[0];
        var reader = new FileReader();

        reader.onload = function (event) {
            encrPrivKey = event.target.result;
            $('#privKeyButton').html(gt('Loaded'));
        };
        reader.readAsText(file);
    }
    
    
    function localDecode(baton, auth, password, extrapass, location) {

        require(['oxguard/crypto/encr', 'oxguard/crypto/jsencrypt'], function (encr, JS) {
            var privkey = window.oxguarddata.priv;
            if (privkey === undefined) privkey = encr.decodeKey(encrPrivKey, password); //Decrypt the private key
            encrPrivKey = null; // null out the global var
            if (privkey === undefined) {
                require (['io.ox/core/notifications'], function (notifications) {
                    //#. User selected wrong or corrupt private key to decode email (Not yet implemented)
                    notifications.yell('error', gt('Bad private key'));
                });
                $('#busygif').hide();
                
            } else {
                var id = baton.data.headers['X-OxGuard-ID'];
                var params = '&itemid=' + id + '&userid=' + ox.user_id + '&cid=' + ox.context_id +
                '&session=' + ox.session;
                // Send the request to the oxguard server for the encrypted content key to decrypt
                $.get(ox.apiRoot + '/oxguard/keys?action=getCKey' + params, function (data) {
                    try {
                        var decrypt = new JS.JSEncrypt();
                        decrypt.setPrivateKey(privkey);
                        var eid = getId(baton);
                        var decodedKey = decrypt.decrypt(data.trim());// Decrypt the content key
                        if ($('input[name="rememberpass' + eid + '"]').is(':checked')) {
                            window.oxguarddata.priv = privkey;
                            var time = $('#duration' + eid) * 1000 * 60;
                            window.setTimeout(function () {
                                window.oxguarddata.priv = undefined;
                            }, time);
                        }
                        require (['oxguard/mail/getmail'], function (reader) {
                            reader.getMail(baton, '', '', extrapass, location, decodedKey);// Get the mail
                        });
                        
                    } catch (e)
                    {
                        console.log(e);
                    }
                })
                .fail(function () {
                    //#. Unable to decode the email
                    require (['io.ox/core/notifications'], function (notifications) {
                        notifications.yell('error', gt('Failed to decrypt'));
                    });

                });
            }
        });

    }
    
    // Unified inbox combines folder and email ID, returns email id
    function getId(baton) {
        var id = decodeURIComponent(baton.data.id);
        try {
            id = id.substring(id.lastIndexOf('/') + 1);
        } catch (e)
            {
            }
        return (id);
    }
    
    function passwordPrompt(baton, badpass, location)
    {
        var id = getId(baton);
        var grdPasswordPrompt = $('<div class="alert" style="width:80%;"/>');
        var mainpassprompt = $('<span style="font-weight:bold;">' + gt('Secure Email, enter your Guard security password') + '</span><div style="height:10px;"/>');
        var passwordbox = $('<input type="password" id="oxgrpass' + id + '" style="margin-bottom:10px;margin-top:7px;"/>');
        var passButton = $('<button class="btn btn-primary oxguard_passbutton" type="button">' + gt('OK') + '</button><br/>');
        var placeholder = $('<span></span><br/>');
        //#. 'Keep me logged into guard' is followed by dropdown box specifying number of minutes or indefinite
        var rememberpass = $('<div><input type="checkbox" name="rememberpass' + id + '" value="true" style="margin-top:-3px;"/><span>&nbsp ' + gt('Keep me logged into Guard') + '</span><br/></div>');
        var duration = $('<select id="duration' + id + '" class="og_duration"><option value="10">' + gt('10 minutes') + '</option>' +
                '<option value="20">' + gt('20 minutes') + '</option>' +
                '<option value="30">' + gt('30 minutes') + '</option>' +
                '<option value="60">' + gt('1 hour') + '</option>' +
                '<option value="120">' + gt('2 hours') + '</option>' +
                '<option value="99999">' + gt('Session') + '</option' +
                '</select>')
                .on('change', function () {
                    $('input[name="rememberpass' + id + '"]').prop('checked', true);
                });
        rememberpass.append(duration);
        //#. Extra passwords can be added to emails for added security.  This is the prompt for it
        var extrapass = $('<span><p style="padding-top:10px;">' + gt('This email was sent with an extra password.') + '<br/>' + 
                //#. Please enter the extra password in the box below
                gt('Please enter below') + ':</p> </span>');
        var extrapassbox = $('<input type="password" id="extrapass' + id + '"/>');
        var cont = $('<br/><div class="error" id = "error' + id + '" style="display:none;"><i class="fa fa-spinner fa-spin" id="busygif"></i></div>');
        if (window.oxguarddata.passcode === 'NoPrivate') {
            if ((window.oxguarddata.priv !== undefined) && (baton.data.headers['X-OxGuard-ExtraPass'] === undefined)) {// If our private key is remembered, just go ahead and decrypt
                localDecode(baton, '', '', '', rememberpass, location);
                return;
            }
            var btn = $('<button class="btn og_getkey" id="privKeyButton' + id + '">' + gt('Select Key Location') + '</button>');

            var input = $('<input type="file" id="files' + id + '" name="files[] style="padding:10px;visibility:hidden;position:absolute;top-50px;left:-50px;"/>');
            btn.click(function () {
                input.click();
            });
            input.change(function (evt) {
                loadKeyClick(evt);
            });
            placeholder.append(btn.after(input));
        }
        passButton.click(go);
        passwordbox.keypress(function (e) {
            if (e.which === 13) {
               // passButton.click();
                go();
            }
        });
        extrapassbox.keypress(function (e) {
            if (e.which === 13) {
                go();
               // passButton.click();
            }
        });
        var mainprompt = (window.oxguarddata.passcode === null) || badpass || (window.oxguarddata.passcode === 'NoPrivate');
        var extraprompt = (baton.data.headers['X-OxGuard-ExtraPass'] === 'true');
        //$('<div class="content"/>').append(grdPasswordPrompt.append(passButton).append(rememberpass).append(cont));
        if (extraprompt && mainprompt) {
            grdPasswordPrompt.append(mainpassprompt).append(passwordbox).append(placeholder).append(rememberpass).append(extrapass).append(extrapassbox).append(passButton).append(cont);
            window.setTimeout(function () {
                passwordbox.focus();
            }, 100);
        }
        if (!extraprompt && mainprompt) {
            grdPasswordPrompt.append(mainpassprompt).append(passwordbox).append(passButton).append(placeholder).append(rememberpass).append(cont);
            window.setTimeout(function () {
                passwordbox.focus();
            }, 100);
        }
        if (extraprompt && !mainprompt) {
            grdPasswordPrompt.append(extrapass).append(extrapassbox).append(passButton).append(placeholder).append(cont);
            window.setTimeout(function () {
                extrapassbox.focus();
            }, 100);
        }
        function go() {
            $('#error' + id).show();
            var password = ($('#oxgrpass' + id).val() === undefined) ? '' : $('#oxgrpass' + id).val();
            var extrapass = ($('#extrapass' + id).val() === undefined) ? '' : $('#extrapass' + id).val();
            var auth = window.oxguarddata.passcode;
            if (auth === 'NoPrivate') {
                localDecode(baton, auth, password, extrapass, location);
                return;
            }
            require (['oxguard/mail/getmail'], function (reader) {
                if (auth === null) {// if no main password, send for auth/temp check
                    if ($('input[name="rememberpass' + id + '"]').is(':checked')) {
                        oxguard.auth(ox.user_id, $('#oxgrpass' + id).val())
                        .done(function (data) {
                            if (data.auth.length > 20) {
                                $('.og_signout').show();
                                window.oxguarddata.passcode = data.auth;
                                reader.getMail(baton, window.oxguarddata.passcode, '', extrapass, location);
                                var time = $('#duration' + id).val() * 1000 * 60;
                                window.setTimeout(function () {
                                    window.oxguarddata.passcode = null;
                                    $('.og_signout').hide();
                                }, time);
                            } else {
                                
                                $('#busygif').hide();
                                require (['io.ox/core/notifications'], function (notifications) {
                                    
                                    if (data.auth.indexOf('Lockout') > -1) {
                                        notifications.yell('error', gt('Temporary Lockout'));
                                    } else {
                                        //#. Bad, incorrect password
                                        notifications.yell('error', gt('Bad password'));
                                    }
                                });
                            }
                        });
                    } else {
                        reader.getMail(baton, auth, password, extrapass, location);
                    }
                } else {
                    reader.getMail(baton, auth, password, extrapass, location);
                }
            });
        }
        
        var contdiv = $('<div class="content" id = "content' + id + '"/>').append(grdPasswordPrompt);
        return (contdiv);
    }
    
   
    
    return {

        passwordPrompt : passwordPrompt
            
    };
    
    
    
});

==> open-xchange-guard-ui_2.0.0.orig.tar.bz2: open-xchange-guard-ui-2.0.0/oxguard-ui/apps/oxguard/mail/oxguard_mail.js <==
/**
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) Open-Xchange Inc., 2006-2011
 */
define('oxguard/mail/oxguard_mail', ['io.ox/core/extensions',
                                     'oxguard/oxguard_core', 'oxguard/core/og_http',
                              'gettext!oxguard/mail/oxguard_mail'],
                              function (ext, oxguard, http, gt) {
    'use strict';
    
    var encrPrivKey = '';

    
    
    ////////////////////////   RECEIVE / READ
    

    
    function loadKeyClick(evt) {
        var file = evt.target.files[0];
        var reader = new FileReader();

        reader.onload = function (event) {
            encrPrivKey = event.target.result;
            $('#privKeyButton').html(gt('Loaded'));
        };
        reader.readAsText(file);
    }
    
    
    function localDecode(baton, auth, password, extrapass, location) {

        require(['oxguard/crypto/encr', 'oxguard/crypto/jsencrypt'], function (encr, JS) {
            var privkey = window.oxguarddata.priv;
            if (privkey === undefined) privkey = encr.decodeKey(encrPrivKey, password); //Decrypt the private key
            encrPrivKey = null; // null out the global var
            if (privkey === undefined) {
                require (['io.ox/core/notifications'], function (notifications) {
                    //#. User selected wrong or corrupt private key to decode email (Not yet implemented)
                    notifications.yell('error', gt('Bad private key'));
                });
                $('#busygif').hide();
                
            } else {
                var id = baton.data.headers['X-OxGuard-ID'];
                var params = '&itemid=' + id + '&userid=' + ox.user_id + '&cid=' + ox.context_id +
                '&session=' + ox.session;
                // Send the request to the oxguard server for the encrypted content key to decrypt
                http.get(ox.apiRoot + '/oxguard/keys?action=getCKey', params)
                .done(function (data) {
                    try {
                        var decrypt = new JS.JSEncrypt();
                        decrypt.setPrivateKey(privkey);
                        var eid = getId(baton);
                        var decodedKey = decrypt.decrypt(data.trim());// Decrypt the content key
                        if ($('input[name="rememberpass' + eid + '"]').is(':checked')) {
                            window.oxguarddata.priv = privkey;
                            var time = $('#duration' + eid) * 1000 * 60;
                            window.setTimeout(function () {
                                window.oxguarddata.priv = undefined;
                            }, time);
                        }
                        require (['oxguard/mail/getmail'], function (reader) {
                            reader.getMail(baton, '', '', extrapass, location, decodedKey);// Get the mail
                        });
                        
                    } catch (e)
                    {
                        console.log(e);
                    }
                })
                .fail(function () {
                    //#. Unable to decode the email
                    require (['io.ox/core/notifications'], function (notifications) {
                        notifications.yell('error', gt('Failed to decrypt'));
                    });

                });
            }
        });

    }
    
    // Unified inbox combines folder and email ID, returns email id
    function getId(baton) {
        var id = decodeURIComponent(baton.data.id);
        try {
            id = id.substring(id.lastIndexOf('/') + 1);
        } catch (e)
            {
            }
        return (id);
    }
    

    
    function passwordPrompt(baton, badpass, location, goFunction)

    {
        var id = getId(baton);
        var grdPasswordPrompt = $('<div class="alert" style="width:80%;"/>');
        var mainpassprompt = $('<span style="font-weight:bold;">' + gt('Secure Email, enter your Guard security password') + '</span><div style="height:10px;"/>');
        var passwordbox = $('<input type="password" id="oxgrpass' + id + '" style="margin-bottom:10px;margin-top:7px;"/>');
        var passButton = $('<button class="btn btn-primary oxguard_passbutton" type="button">' + gt('OK') + '</button><br/>');
        var placeholder = $('<span></span><br/>');
        //#. 'Keep me logged into guard' is followed by dropdown box specifying number of minutes or indefinite
        var remembertext = $('<span class="selectable">&nbsp ' + gt('Keep me logged into Guard') + '</span><br/>');
        var rememberpass = $('<div><input type="checkbox" name="rememberpass' + id + '" value="true" style="margin-top:-3px;"/></div>');
        var duration = $('<select id="duration' + id + '" class="og_duration"><option value="10">' + gt('10 minutes') + '</option>' +
                '<option value="20">' + gt('20 minutes') + '</option>' +
                '<option value="30">' + gt('30 minutes') + '</option>' +
                '<option value="60">' + gt('1 hour') + '</option>' +
                '<option value="120">' + gt('2 hours') + '</option>' +
                '<option value="99999">' + gt('Session') + '</option' +
                '</select>')
                .on('change', function () {
                    $('input[name="rememberpass' + id + '"]').prop('checked', true);
                });
        rememberpass.append(remembertext).append(duration);
        remembertext.click(function () {
            $('[name="rememberpass' + id + '"]').click();
        });
        //#. Extra passwords can be added to emails for added security.  This is the prompt for it
        var extrapass = $('<span><p style="padding-top:10px;">' + gt('This email was sent with an extra password.') + '<br/>' + 
                //#. Please enter the extra password in the box below
                gt('Please enter below') + ':</p> </span>');
        var extrapassbox = $('<input type="password" id="extrapass' + id + '"/>');
        var cont = $('<br/><div class="error" id = "error' + id + '" style="display:none;"><i class="fa fa-spinner fa-spin" id="busygif"></i></div>');
        if (window.oxguarddata.passcode === 'NoPrivate') {
            if ((window.oxguarddata.priv !== undefined) && (baton.data.headers['X-OxGuard-ExtraPass'] === undefined)) {// If our private key is remembered, just go ahead and decrypt
                localDecode(baton, '', '', '', rememberpass, location);
                return;
            }
            var btn = $('<button class="btn og_getkey" id="privKeyButton' + id + '">' + gt('Select Key Location') + '</button>');

            var input = $('<input type="file" id="files' + id + '" name="files[] style="padding:10px;visibility:hidden;position:absolute;top-50px;left:-50px;"/>');
            btn.click(function () {
                input.click();
            });
            input.change(function (evt) {
                loadKeyClick(evt);
            });
            placeholder.append(btn.after(input));
        }
        passButton.click(function () {
            go();
        });
        passwordbox.keypress(function (e) {
            if (e.which === 13) {
               // passButton.click();
                go();
            }
        });
        extrapassbox.keypress(function (e) {
            if (e.which === 13) {
                go();            
               // passButton.click();
            }
        });
        var mainprompt = (window.oxguarddata.passcode === null) || badpass || (window.oxguarddata.passcode === 'NoPrivate');
        var extraprompt = (baton.data.headers['X-OxGuard-ExtraPass'] === 'true');
        //$('<div class="content"/>').append(grdPasswordPrompt.append(passButton).append(rememberpass).append(cont));
        if (extraprompt && mainprompt) {
            grdPasswordPrompt.append(mainpassprompt).append(passwordbox).append(placeholder).append(rememberpass).append(extrapass).append(extrapassbox).append(passButton).append(cont);
            window.setTimeout(function () {
                passwordbox.focus();
            }, 1);
        }
        if (!extraprompt && mainprompt) {
            grdPasswordPrompt.append(mainpassprompt).append(passwordbox).append(passButton).append(placeholder).append(rememberpass).append(cont);
            window.setTimeout(function () {
                passwordbox.focus();
            }, 1);
        }
        if (extraprompt && !mainprompt) {
            grdPasswordPrompt.append(extrapass).append(extrapassbox).append(passButton).append(placeholder).append(cont);
            window.setTimeout(function () {
                extrapassbox.focus();
            }, 1);
        }
        
        function go() {
            $('#error' + id).show();
            var password = ($('#oxgrpass' + id).val() === undefined) ? '' : $('#oxgrpass' + id).val();
            var extrapass = ($('#extrapass' + id).val() === undefined) ? '' : $('#extrapass' + id).val();
            var auth = window.oxguarddata.passcode;
            if (auth === 'NoPrivate') {
                localDecode(baton, auth, password, extrapass, location);
                return;
            }
            require (['oxguard/mail/getmail'], function (reader) {
                if (auth === null) {// if no main password, send for auth/temp check
                    if ($('input[name="rememberpass' + id + '"]').is(':checked')) {
                        oxguard.auth(ox.user_id, $('#oxgrpass' + id).val())
                        .done(function (data) {
                            if (data.auth.length > 20) {
                                $('.og_signout').show();
                                window.oxguarddata.passcode = data.auth;
                                if (goFunction !== undefined) {
                                    goFunction (id);
                                } else
                                    reader.getMail(baton, window.oxguarddata.passcode, '', extrapass, location);
                                var time = $('#duration' + id).val() * 1000 * 60;
                                window.setTimeout(function () {
                                    window.oxguarddata.passcode = null;
                                    $('.og_signout').hide();
                                }, time);
                            } else {
                                $('#busygif').hide();
                                require (['io.ox/core/notifications'], function (notifications) {
                                    
                                    if (data.auth.indexOf('Lockout') > -1) {
                                        notifications.yell('error', gt('Temporary Lockout'));
                                    } else {
                                        //#. Bad, incorrect password
                                        notifications.yell('error', gt('Bad password'));
                                    }
                                });
                            }
                        });
                    } else {
                        if (goFunction !== undefined) {
                            goFunction (id);
                        } else 
                            reader.getMail(baton, auth, password, extrapass, location);
                    }
                } else {
                    if (goFunction !== undefined) {
                        goFunction (id);
                    } else
                        reader.getMail(baton, auth, password, extrapass, location);
                }
            });
        }
        
        var contdiv = $('<div class="content" id = "content' + id + '"/>').append(grdPasswordPrompt);
        return (contdiv);
    }
    
   
    
    return {

        passwordPrompt : passwordPrompt
            
    };
    
    
    
});
